DeferredRouteDefinition class

Inheritance

Properties

additionalData → dynamic
Additional information to attached to the RouteDefinition.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
loader → LoadComponentAsync
Returns a future that completes with a component type to be resolved.
final
parameters → Iterable<String>
Collection of parameters that are supplied in path.
no setterinherited
path → String
Logical name used for determining a route.
finalinherited
prefetcher → FutureOr<void> Function(RouterState)?
An optional function for prefetching resources before loading this route.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useAsDefault → bool
Uses this Route as default if the RouterOutlet has no component.
finalinherited

Methods

assertValid() → void
Runs a dev-mode assertion that the definition is valid.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRegExp() → RegExp
Returns as a regular expression that matches this route.
inherited
toString() → String
A string representation of this object.
inherited
toUrl([Map<String, String> paramValues = const {}]) → String
Returns as a valid URL with paramValues filled into parameters.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited